package com.sensor.iot.api.service;

import com.github.lianjiatech.retrofit.spring.boot.core.RetrofitClient;
import com.sensor.iot.api.annotation.Auth;
import com.sensor.iot.api.model.ApiResp;
import com.sensor.iot.api.model.PropQuery;
import com.sensor.iot.api.model.QueryResp;
import com.sensor.iot.api.model.TslHistoryQuery;
import retrofit2.http.GET;
import retrofit2.http.Query;
import retrofit2.http.QueryMap;

import java.util.Map;

/**
 * DeviceTslApiService
 *
 * @author Frank
 */
@RetrofitClient(baseUrl = "${sensor.iot.api.baseUrl}")
@Auth(clientId = "${sensor.iot.api.clientId}", clientSecret = "${sensor.iot.api.clientSecret}")
public interface DeviceTslApiService {

    /**
     * 查询指定设备属性值
     *
     * @param query {@link PropQuery}
     * @return {@link ApiResp}
     */
    @GET("/iot/api/tsl/prop")
    ApiResp<Map<String, Object>> queryProp(@QueryMap Map<String, Object> query);

    default ApiResp<Map<String, Object>> queryProp(@QueryMap PropQuery query) {
        return queryProp(query.toMap());
    }


    /**
     * 查询指定设备最新属性数据
     *
     * @param deviceId 设备编号
     * @return {@link ApiResp}
     */
    @GET("/iot/api/tsl/prop/latest")
    ApiResp<Map<String, Object>> queryPropLatest(@Query("deviceId") String deviceId);


    /**
     * 查询设备属性历史数据
     *
     * @param query {@link TslHistoryQuery}
     * @return {@link QueryResp}
     */
    @GET("/iot/api/tsl/propHistory")
    QueryResp<Map<String, Object>> queryPropHistory(@QueryMap Map<String, Object> query);

    default QueryResp<Map<String, Object>> queryPropHistory(@QueryMap TslHistoryQuery query) {
        return queryPropHistory(query.toMap());
    }

    /**
     * 查询设备事件历史数据
     *
     * @param query {@link TslHistoryQuery}
     * @return {@link QueryResp}
     */
    @GET("/iot/api/tsl/eventHistory")
    QueryResp<Map<String, Object>> queryEventHistory(@QueryMap Map<String, Object> query);

    default QueryResp<Map<String, Object>> queryEventHistory(@QueryMap TslHistoryQuery query) {
        return queryEventHistory(query.toMap());
    }

    /**
     * 查询设备功能操作历史
     *
     * @param query {@link TslHistoryQuery}
     * @return {@link QueryResp}
     */
    @GET("/iot/api/tsl/func/history")
    QueryResp<Map<String, Object>> queryFuncHistory(@QueryMap Map<String, Object> query);

    default QueryResp<Map<String, Object>> queryFuncHistory(@QueryMap TslHistoryQuery query) {
        return queryFuncHistory(query.toMap());
    }


}
